==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/FilterFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import me.snowdrop.istio.api.StructFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Struct;
import java.lang.Deprecated;
import javax.validation.Valid;
import me.snowdrop.istio.api.StructBuilder;
import java.lang.Boolean;

public interface FilterFluent<A extends FilterFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildFilterConfig instead.
 * @return The buildable object.
 */
@Deprecated public Struct getFilterConfig();
    public Struct buildFilterConfig();
    public A withFilterConfig(Struct filterConfig);
    public Boolean hasFilterConfig();
    public FilterFluent.FilterConfigNested<A> withNewFilterConfig();
    public FilterFluent.FilterConfigNested<A> withNewFilterConfigLike(Struct item);
    public FilterFluent.FilterConfigNested<A> editFilterConfig();
    public FilterFluent.FilterConfigNested<A> editOrNewFilterConfig();
    public FilterFluent.FilterConfigNested<A> editOrNewFilterConfigLike(Struct item);
    public String getFilterName();
    public A withFilterName(String filterName);
    public Boolean hasFilterName();
    public FilterType getFilterType();
    public A withFilterType(FilterType filterType);
    public Boolean hasFilterType();
    
/**
 * This method has been deprecated, please use method buildInsertPosition instead.
 * @return The buildable object.
 */
@Deprecated public InsertPosition getInsertPosition();
    public InsertPosition buildInsertPosition();
    public A withInsertPosition(InsertPosition insertPosition);
    public Boolean hasInsertPosition();
    public FilterFluent.InsertPositionNested<A> withNewInsertPosition();
    public FilterFluent.InsertPositionNested<A> withNewInsertPositionLike(InsertPosition item);
    public FilterFluent.InsertPositionNested<A> editInsertPosition();
    public FilterFluent.InsertPositionNested<A> editOrNewInsertPosition();
    public FilterFluent.InsertPositionNested<A> editOrNewInsertPositionLike(InsertPosition item);
    
/**
 * This method has been deprecated, please use method buildListenerMatch instead.
 * @return The buildable object.
 */
@Deprecated public ListenerMatch getListenerMatch();
    public ListenerMatch buildListenerMatch();
    public A withListenerMatch(ListenerMatch listenerMatch);
    public Boolean hasListenerMatch();
    public FilterFluent.ListenerMatchNested<A> withNewListenerMatch();
    public FilterFluent.ListenerMatchNested<A> withNewListenerMatchLike(ListenerMatch item);
    public FilterFluent.ListenerMatchNested<A> editListenerMatch();
    public FilterFluent.ListenerMatchNested<A> editOrNewListenerMatch();
    public FilterFluent.ListenerMatchNested<A> editOrNewListenerMatchLike(ListenerMatch item);

    public interface FilterConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StructFluent<FilterFluent.FilterConfigNested<N>>{

        
    public N and();    public N endFilterConfig();
}
    public interface InsertPositionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InsertPositionFluent<FilterFluent.InsertPositionNested<N>>{

        
    public N and();    public N endInsertPosition();
}
    public interface ListenerMatchNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListenerMatchFluent<FilterFluent.ListenerMatchNested<N>>{

        
    public N and();    public N endListenerMatch();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/FilterFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import me.snowdrop.istio.api.StructFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Struct;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import me.snowdrop.istio.api.StructBuilder;
import java.lang.Boolean;

public interface FilterFluent<A extends FilterFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildFilterConfig instead.
 * @return The buildable object.
 */
@Deprecated public Struct getFilterConfig();
    public Struct buildFilterConfig();
    public A withFilterConfig(Struct filterConfig);
    public Boolean hasFilterConfig();
    public FilterFluent.FilterConfigNested<A> withNewFilterConfig();
    public FilterFluent.FilterConfigNested<A> withNewFilterConfigLike(Struct item);
    public FilterFluent.FilterConfigNested<A> editFilterConfig();
    public FilterFluent.FilterConfigNested<A> editOrNewFilterConfig();
    public FilterFluent.FilterConfigNested<A> editOrNewFilterConfigLike(Struct item);
    public String getFilterName();
    public A withFilterName(String filterName);
    public Boolean hasFilterName();
    public A withNewFilterName(String arg1);
    public A withNewFilterName(StringBuilder arg1);
    public A withNewFilterName(StringBuffer arg1);
    public FilterType getFilterType();
    public A withFilterType(FilterType filterType);
    public Boolean hasFilterType();
    
/**
 * This method has been deprecated, please use method buildInsertPosition instead.
 * @return The buildable object.
 */
@Deprecated public InsertPosition getInsertPosition();
    public InsertPosition buildInsertPosition();
    public A withInsertPosition(InsertPosition insertPosition);
    public Boolean hasInsertPosition();
    public FilterFluent.InsertPositionNested<A> withNewInsertPosition();
    public FilterFluent.InsertPositionNested<A> withNewInsertPositionLike(InsertPosition item);
    public FilterFluent.InsertPositionNested<A> editInsertPosition();
    public FilterFluent.InsertPositionNested<A> editOrNewInsertPosition();
    public FilterFluent.InsertPositionNested<A> editOrNewInsertPositionLike(InsertPosition item);
    
/**
 * This method has been deprecated, please use method buildListenerMatch instead.
 * @return The buildable object.
 */
@Deprecated public ListenerMatch getListenerMatch();
    public ListenerMatch buildListenerMatch();
    public A withListenerMatch(ListenerMatch listenerMatch);
    public Boolean hasListenerMatch();
    public FilterFluent.ListenerMatchNested<A> withNewListenerMatch();
    public FilterFluent.ListenerMatchNested<A> withNewListenerMatchLike(ListenerMatch item);
    public FilterFluent.ListenerMatchNested<A> editListenerMatch();
    public FilterFluent.ListenerMatchNested<A> editOrNewListenerMatch();
    public FilterFluent.ListenerMatchNested<A> editOrNewListenerMatchLike(ListenerMatch item);

    public interface FilterConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StructFluent<FilterFluent.FilterConfigNested<N>>{

        
    public N and();    public N endFilterConfig();
}
    public interface InsertPositionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InsertPositionFluent<FilterFluent.InsertPositionNested<N>>{

        
    public N and();    public N endInsertPosition();
}
    public interface ListenerMatchNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListenerMatchFluent<FilterFluent.ListenerMatchNested<N>>{

        
    public N and();    public N endListenerMatch();
}


}
